@@ -21,11 +21,11 @@ Net::eBay - Perl Interface to XML based eBay API.
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =cut
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 =head1 SYNOPSIS
 
@@ -452,8 +452,11 @@ sub verifyAndPrint {
 
 sub UTF8 {
   my $x = shift @_;
+  return $x unless defined $x;
   utf8::upgrade($x);
+
   return $x;
+  #return "[!CDATA[$x]]";
 }
 
 sub hash2xml {
